sample = {
    "resource": "/{proxy+}",
    "path": "/work",
    "httpMethod": "POST",
    "headers": {
        "Accept": "*/*",
        "CloudFront-Forwarded-Proto": "https",
        "CloudFront-Is-Desktop-Viewer": "true",
        "CloudFront-Is-Mobile-Viewer": "false",
        "CloudFront-Is-SmartTV-Viewer": "false",
        "CloudFront-Is-Tablet-Viewer": "false",
        "CloudFront-Viewer-Country": "US",
        "content-type": "application/json",
        "Host": "66ivosvo25.execute-api.us-east-1.amazonaws.com",
        "User-Agent": "curl/7.68.0",
        "Via": "2.0 de2ed3c94563fee614f35f9bc3f52d1c.cloudfront.net (CloudFront)",
        "X-Amz-Cf-Id": "8LodH__BWnXodDK3Ejh-P6I7ZFKJYemE4ietXtkBd2nk7G5rH76haQ==",
        "X-Amzn-Trace-Id": "Root=1-60e8c842-304495781b0ba1e30b532d82",
        "X-Forwarded-For": "35.168.174.90, 130.176.98.91",
        "X-Forwarded-Port": "443",
        "X-Forwarded-Proto": "https"
    },
    "multiValueHeaders": {
        "Accept": [
            "*/*"
        ],
        "CloudFront-Forwarded-Proto": [
            "https"
        ],
        "CloudFront-Is-Desktop-Viewer": [
            "true"
        ],
        "CloudFront-Is-Mobile-Viewer": [
            "false"
        ],
        "CloudFront-Is-SmartTV-Viewer": [
            "false"
        ],
        "CloudFront-Is-Tablet-Viewer": [
            "false"
        ],
        "CloudFront-Viewer-Country": [
            "US"
        ],
        "content-type": [
            "application/json"
        ],
        "Host": [
            "66ivosvo25.execute-api.us-east-1.amazonaws.com"
        ],
        "User-Agent": [
            "curl/7.68.0"
        ],
        "Via": [
            "2.0 de2ed3c94563fee614f35f9bc3f52d1c.cloudfront.net (CloudFront)"
        ],
        "X-Amz-Cf-Id": [
            "8LodH__BWnXodDK3Ejh-P6I7ZFKJYemE4ietXtkBd2nk7G5rH76haQ=="
        ],
        "X-Amzn-Trace-Id": [
            "Root=1-60e8c842-304495781b0ba1e30b532d82"
        ],
        "X-Forwarded-For": [
            "35.168.174.90, 130.176.98.91"
        ],
        "X-Forwarded-Port": [
            "443"
        ],
        "X-Forwarded-Proto": [
            "https"
        ]
    },
    "queryStringParameters": None,
    "multiValueQueryStringParameters": None,
    "pathParameters": {
        "proxy": "work"
    },
    "stageVariables": None,
    "requestContext": {
        "resourceId": "9qz2u9",
        "resourcePath": "/{proxy+}",
        "httpMethod": "POST",
        "extendedRequestId": "COQ6fFKnIAMFUhw=",
        "requestTime": "09/Jul/2021:22:05:54 +0000",
        "path": "/dev/work",
        "accountId": "018734038160",
        "protocol": "HTTP/1.1",
        "stage": "dev",
        "domainPrefix": "66ivosvo25",
        "requestTimeEpoch": 1625868354933,
        "requestId": "0372d9c2-9f79-4368-9547-a1d418404da9",
        "identity": {
            "cognitoIdentityPoolId": None,
            "accountId": None,
            "cognitoIdentityId": None,
            "caller": None,
            "sourceIp": "35.168.174.90",
            "principalOrgId": None,
            "accessKey": None,
            "cognitoAuthenticationType": None,
            "cognitoAuthenticationProvider": None,
            "userArn": None,
            "userAgent": "curl/7.68.0",
            "user": None
        },
        "domainName": "66ivosvo25.execute-api.us-east-1.amazonaws.com",
        "apiId": "66ivosvo25"
    },
    "body": "eyJ4IjogNDJ9",
    "isBase64Encoded": True
}
